.. _download:

Downloading aubio
=================

A number of distributions already include aubio. Check your favorite package
management system, or have a look at the `aubio download page
<https://aubio.org/download>`_ for more options.

To use aubio in an android project, see :ref:`android`.

To compile aubio from source, read :ref:`building`.

.. include:: binaries.rst

.. include:: debian_packages.rst
